@@ -30,3 +30,13 @@ class HSResult:
     def withData(self,data):
         self.data = data
         return self
+
+
+def line(number):
+    if number == None:
+        number = 0
+    print("\n\n<%s> ----------------------"
+          "---------------------------"
+          "---------------------------"
+          "---------------------------"
+          "------------"%(number))
